<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 */

class Carerix_Api_Rest_Collection extends ArrayObject {
    
    /**
     * Hydrates each record in a collection to array
     * 
     * @return array
     */
    public function toArray() {
        $array = array();
        foreach($this as $record) {
            if(!$record instanceof Carerix_Api_Rest_Entity &&
                !$record instanceof Carerix_Api_Rest_Collection) {
                continue;
            }
            $array[] = $record->toArray();
        }
        return $array;
    }
        
    /**
     * Hydrates collection to XML document
     * 
     * @return string XML document
     */
    public function toXml() {
        $xml = array();
        $xml[] = '<array count="'.$this->getTotalCount().'">';
        foreach($this as $record) {
            if(!$record instanceof Carerix_Api_Rest_Entity && 
                !$record instanceof Carerix_Api_Rest_Collection) {
                continue;
            }        
            $xml[] = trim(str_replace('<?xml version="1.0"?>', '', $record->toXML()));
        }
        $xml[] = '</array>';
        return implode('', $xml);
    }
    
    /**
     * Total # of records.
     * 
     * count
     * @var integer
     */
    protected $totalCount;
    
    /**
     * Gets count
     *
     * @return integer
     */
    public function getTotalCount() 
    {
        return $this->totalCount;
    }
    
    /**
     * Sets count
     *
     * @param integer $count count
     * @return self
     */
    public function setTotalCount($totalCount) 
    {
        $this->totalCount = $totalCount;
        return $this;
    }
    
}