<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 */

class Carerix_Api_Rest_DataType_NSArray extends ArrayObject implements Carerix_Api_Rest_DataType_Interface {
    const DATA_TYPE = 'NSArray';
    
    /**
     * Converts array into class instance.
     * 
     * @param array $array
     * @return Carerix_Api_Rest_DataType_NSArray
     */
    public static function fromArray($array) {
        $values = array();
        foreach($array as $k => $v) {
            switch(true) {
                case $k == Carerix_Api_Rest_DataType_NSDictionary::DATA_TYPE:
                    $type = 'Carerix_Api_Rest_DataType_NSDictionary';
                    break;
                
                case substr($k, 0, 2) == 'CR':
                    $type = Carerix_Api_Rest_EntityGenerator::ABSTRACT_CLASS.'_'.Carerix_Api_Rest_EntityGenerator::fromXmlEntityName($k);
                    break;
                
                default:
                    continue;
            }
            if(!array_key_exists(0, $v)) {
                $v = array();
            }
            foreach($v as $kk => $vv) {
                $values[] = new $type($vv);
            }            
        }
        return new Carerix_Api_Rest_DataType_NSArray($values);
    }
    
    /**
     * @return array 
     */
    public function toArray() {
        $array = array();
        foreach($this as $k => $v) {
            if($v instanceof Carerix_Api_Rest_DataType_NSDictionary ||
                $v instanceof Carerix_Api_Rest_Entity) {
                $array[$k] = $v->toArray();
            }
        }
        return $array;
    }
    
    /**
     * 
     * @param array $values
     * @param SimpleXMLElement $sxe
     * @return SimpleXMLElement
     */
    public function toSimpleXMLElement(&$sxe = null) {
        foreach($this as $k => $v) {
            if($v instanceof Carerix_Api_Rest_DataType_NSDictionary) {
                $v->toSimpleXMLElement($sxe->{Carerix_Api_Rest_DataType_NSDictionary::DATA_TYPE}[]);
            }
            else if($v instanceof Carerix_Api_Rest_Entity) {
                $entity = Carerix_Api_Rest_Entity::getEntityFromObject($v);
                $v->toSimpleXMLElement($sxe->{'CR'.$entity}, $v);
            }
        }            
        
        return $sxe;
    }
}