<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 */

class Carerix_Api_Rest_DataType_NSDictionary extends ArrayObject implements Carerix_Api_Rest_DataType_Interface {
    const DATA_TYPE = 'NSDictionary';
    
    /**
     * Converts array into class instance.
     * 
     * @param array $array
     * @return Carerix_Api_Rest_DataType_NSDictionary
     */
    public static function fromArray($array) {
        $values = array();
        foreach($array as $k => $v) {
            if(substr($k, 0, 1) == '_') {
                $k = substr($k, 1);                    
            }
            $values[$k] = $v;
        }
        return new Carerix_Api_Rest_DataType_NSDictionary($values);
    }
        
    /**
     * Hydrates each record in a collection to array
     * 
     * @return array
     */
    public function toArray() {
        $array = array();
        foreach($this as $k => $v) {
            //key that is not a valid XML element name (because it starts with a digit, for example) is prefixed with an underscore. 
            if(substr($k, 0, 1) == '_') {
                $k = substr($k, 1);                    
            }
            $array[$k] = $v;    
        }
        return $array;
    }
    
    /**
     * 
     * Enter description here ...
     * @param array $values
     * @param SimpleXMLElement $sxe
     * @return SimpleXMLElement
     */
    public function toSimpleXMLElement(&$sxe = null) {
        if($sxe === null) {
            $sxe = new SimpleXMLElement('<'.self::DATA_TYPE.'/>');
            }    
        foreach($this as $k => $v) {
            //key that is not a valid XML element name (because it starts with a digit, for example) is prefixed with an underscore. 
            if(!preg_match(self::XML_ELEMENT_NAME_REGEX, $k)) {
                $k = '_'.$k;
            }
//            $sxe->{self::DATA_TYPE}->$k = $v;
            $sxe->$k = $v;
        }            
        
        return $sxe;
    }
}