<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/*
 *  $Id$
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the LGPL. For more information, see
 * <http://www.doctrine-project.org>.
*/

/**
 * Abstract entity class for REST entities to extend from to give ActiveRecord
 * style interface for working with REST services.
 *
 * @license     http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link        www.doctrine-project.org
 * @since       2.0
 * @version     $Revision$
 * @author      Jonathan H. Wage <jonwage@gmail.com>
 */

/**
 * Port to PHP 5.2 w/ custom functionality, methods and docs
 * @author        Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @todo XML element mapping: transient.*, transient.tid, transient.nid, transient.group, transient.frequency 
 */
abstract class Carerix_Api_Rest_Entity
{
    const DATE_FORMAT = 'Y-m-d H:i:s O';
    const XML_ELEMENT_NAME_REGEX = '/\A(?!XML)[a-z][\w0-9-]*/i';
    
    /**
     * PHP object - Carerix_Api_Rest_Entity|Carerix_Api_Rest_Collection
     * @var integer
     */
    const HYDRATE_OBJECT = 1;
    
    /**
     * Raw response from the REST API
     * @var integer
     */    
    const HYDRATE_NONE = 2;
    
    /**
     * Array obtained by unserializing raw response from the REST API
     * @var integer
     */        
    const HYDRATE_ARRAY = 3;
    
    /**
     * XML document obtained by hydrating PHP object
     * @var integer
     */        
    const HYDRATE_OBJECT_XML = 4;
    
    /**
     * Array obtained by hydrating PHP object
     * @var integer
     */        
    const HYDRATE_OBJECT_ARRAY = 5;
    
    /**
     * 
     * @var Carerix_Api_Rest_Manager
     */
    protected static $_manager;

    /**
     * Constructor
     * 
     * @param array $values [optional]
     * @return void
     */
    public function __construct(array $values = null) {
        if($values !== null) {
            $this->fromArray($values);
        }
    }
    
    /**
     * 
     * @param Carerix_Api_Rest_Manager $manager
     * @return void
     */
    public static function setManager(Carerix_Api_Rest_Manager $manager)
    {
        self::$_manager = $manager;
    }

       /**
        * 
        * @return Carerix_Api_Rest_Manager;
        */
    public static function getManager()
    {
        return self::$_manager;
    }
    
    /**
     * Return entity as XML document.
     * 
     * @return string XML document
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */
    public function toXml()
    {
        $sxe = $this->toSimpleXMLElement();
        $xml = $sxe->asXML();
        return $xml;
    }

    /**
     * Template method.
     * 
     * @param Carerix_Api_Rest_EntityConfiguration $entityConfiguration
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */
    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {

    }    

    /**
     * 
     * Get entity name from php object.
     * 
     * Example: Carerix_Api_Rest_Entity_To_Do -> toDo
     * 
     * @param object $object
     * @return string
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */
    public static function getEntityFromObject($object) {
        if(is_object($object)) {
            $entity = get_class($object);
        }
        elseif(is_string($object)) {
            $entity = $object;
        }
        else {
            return null;
        }
        $entity = substr($entity, strlen(__CLASS__.'_'));
        $entity = str_replace('_', '', $entity);  
        return $entity;      
    }
    
    /**
     * Create XML document
     * 
     * @param SimpleXMLElement $sxe
     * @param object $context
     * @return SimpleXMLElement
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */
    public function toSimpleXMLElement(&$sxe = null, $context = null)
    {
        if($context === null) {
            $context = $this;
        }

        $vars = get_object_vars($context);
        
        $entity = self::getEntityFromObject($context);
 
        if($sxe === null) {
            $sxe = new SimpleXMLElement('<CR'.$entity.'/>');
            }
     
        $entityID = $entity.'ID';
        if(array_key_exists($entityID, $vars)) {
               $sxe['id'] = $vars[$entityID];
        }
        
        // inject attributes into root node
        if(array_key_exists('attributes', $vars) && !empty($vars['attributes'])) {
               foreach($vars['attributes'] as $k => $v) {
                   $sxe[$k] = $v;
               }
               unset($vars['attributes']);
        }

        foreach($vars as $k => $v) {
            if($v == null) {
                continue;
            }
                    // Note: when saving, you must leave out the NSArray element! 
            // This is a known bug. 
            // The NSArray element will be eliminated completely in a future release.
            if($v instanceof Carerix_Api_Rest_DataType_NSArray) {
//                 foreach($v as $vv) {
//                    if($vv instanceof Carerix_Api_Rest_DataType_NSDictionary) {
//                        
//                        $vv->toSimpleXMLElement($sxe->{$k});
//                    }                  
//                }                
//                $sxe->{$k};
//                foreach($v as $vv) {
                    $v->toSimpleXMLElement($sxe->{$k});    
//                }                
            }            
            else if($v instanceof Carerix_Api_Rest_DataType_NSDictionary) {
                $v->toSimpleXMLElement($sxe);
            }

            else if($v instanceof Carerix_Api_Rest_Collection) {
                foreach($v as $vv) {
                    if($vv instanceof Carerix_Api_Rest_Entity) {
                        $entity = self::getEntityFromObject($vv);
                        $this->toSimpleXMLElement($sxe->{$k}->{'CR'.$entity}[], $vv);
                    }                  
                }
            }
            else if(is_array($v)) {
                foreach($v as $vv) {
                    $sxe->{$k} = $vv;                
                }
            }
            else {
                if($v instanceof Carerix_Api_Rest_Entity) {
                    $entity = self::getEntityFromObject($v);
                    $this->toSimpleXMLElement($sxe->{$k}->{'CR'.$entity}, $v);
                }
                else {
                    $sxe->{$k} = $v;
                }
            }
        }
        return $sxe;
    }     

    /**
     * Check if the record exists.
     * 
     * @return boolean
     */
    public function exists()
    {
        return self::$_manager->entityExists($this);
    }

    /**
     * Get record identifier
     * @return string
     */
    public function getIdentifierProxy()
    {
        return self::$_manager->getEntityIdentifier($this);
    }

    /**
     * 
     * Generates a request URL
     * 
     * @return string
     */    
    public static function generateUrl(array $options = array(), $get_called_class = null)
    {
        if($get_called_class === null) {
            $get_called_class = get_called_class(); 
        }
        $configuration = self::$_manager->getEntityConfiguration($get_called_class);
        return $configuration->generateUrl($options);
    }   

    /**
     * Find an entity.
     * 
     * @param string $id
     * @param array $parameters[optional]
     * @param integer $hydrate[optional] hydration method
     * 
     * @author Jonathan H. Wage <jonwage@gmail.com>
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * 
     * @return Carerix_Api_Rest_Entity|null
     */
    public static function find($id, $parameters = null, $hydrate = null)
    {
        $args = func_get_args();
        switch(count($args)) {
            case 1:
                $parameters = null;
                $hydrate = null;               
            break;
            
            case 2:
                $hydrate = null;
                   if(!is_array($args[1])) {
                    $parameters = null;
                    $hydrate = $args[1];
                }            
            break;
        }
        
        $get_called_class = get_called_class();
        
        return self::$_manager->execute(
            $get_called_class,
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            $parameters,
            null,
            $hydrate
        );
    }

    /**
     * Get a colleciton of entities.
     * 
     * @param string $action [optional|default:list] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * @param integer $hydrate[optional] hydration method
     * 
     * @author Jonathan H. Wage <jonwage@gmail.com>
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * 
     * @return Carerix_Api_Rest_Entity_Collection|null collection object on success, null on failure.
     */
    public static function findAll($action = 'list', $parameters = null, $hydrate = null)
    {
        $args = func_get_args();
        if(!empty($args) && is_array($args[0])) {
            $action = 'list';
            $parameters = $args[0];
            if(array_key_exists(1, $args)) {
                $hydrate = $args[1];
            } 
        }
        $get_called_class = get_called_class();
        return self::$_manager->execute(
            $get_called_class,
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            $parameters,
            null,
            $hydrate
        );
    }

    /**
     * Save an object.
     * 
     * @param string $action [optional] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * 
     * @author Jonathan H. Wage <jonwage@gmail.com>
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * 
     * @return Carerix_Api_Rest_Entity
     */
    public function save($action = null, $parameters = null)
    {
        $get_called_class = get_class($this);
        
        $exists = $this->exists();
        $method = $exists ? Carerix_Api_Rest_Client::PUT : Carerix_Api_Rest_Client::POST;
        $id = $exists ? $this->getIdentifierProxy() : null;
        $path = $this->generateUrl(get_defined_vars(), $get_called_class);
        return self::$_manager->execute($this, $path, $method, $parameters, $this->toXml());
    }

    /**
     * Delete an object.
     * 
     * @param string $action [optional] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * 
     * @author Jonathan H. Wage <jonwage@gmail.com>
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     *  
     * @return Carerix_Api_Rest_Entity
     */
    public function delete($action = null, $parameters = null)
    {
        $get_called_class = get_class($this);
        
        $id = $this->getIdentifierProxy();
        return self::$_manager->execute(
            $this, 
            $this->generateUrl(get_defined_vars(), $get_called_class), 
            Carerix_Api_Rest_Client::DELETE
        );
    }

    /**
     * Update an object.
     * 
     * @param string $action [optional] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * @return Carerix_Api_Rest_Entity
     */
    public function post($action = null, $parameters = null)
    {
        $get_called_class = get_class($this);
        
        $id = $this->getIdentifierProxy();
        return self::$_manager->execute(
            $this, 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::POST,
            $parameters,
            $this->toXml()
        );
    }

    /**
     * Get an object.
     * 
     * @param string $action [optional] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * @param integer $hydrate [optional] hydration method
     * @return Carerix_Api_Rest_Entity
     */    
    public function get($action = null, $parameters = null, $hydrate = null)
    {
        $get_called_class = get_class($this);
        
        return self::$_manager->execute(
            $this, 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate
        );
    }

    /**
     * Create a new object.
     * 
     * @param string $action [optional] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * @return Carerix_Api_Rest_Entity
     */    
    public function put($action = null, $parameters = null)
    {
        $get_called_class = get_class($this);
        
        return self::$_manager->execute(
            $this, 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::PUT, 
            $parameters,
            $this->toXml()
        );
    }

    /**
     * Execute a generic call to the REST API 
     * 
     * @param string $method HTTP verb: GET, POST, etc.
     * @param string $action [optional] specifiy a different action name to invoke.
     * @param array $parameters [optional] any extra GET parameters to send.
     * @param string $body [optional] request body
     * @param integer $hydrate [optional] hydration method
     * 
     * @rerturn mixed
     */    
    public static function execute($method, $action, $parameters = null, $body = null, $hydrate = null)
    {
        $get_called_class = get_called_class();
        
        return self::$_manager->execute(
            $get_called_class(),
            self::generateUrl(get_defined_vars(), $get_called_class),
            $method, 
            $parameters,
            $body,
            $hydrate
        );
    }
    
    /**
     * Get an attachment.
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * 
     * @param array $parameters e.g. array('tag' => 'logo', 'show' => array('label', 'filePath'), 'language' => 'English')
     * @param integer $hydrate [optional] hydration method
     * 
     * @return mixed Carerix_Api_Rest_Collection of Carerix_Api_Rest_Entity_To_Do objects|array|raw
     * 
     * @see http://development.wiki.carerix.com/index.php/Cxrest_API_methods#GET_.24object.2Fattachment
     */
    public function attachment(array $parameters, $hydrate = null)
    {
        $get_called_class = get_class($this);
        if($get_called_class == 'Carerix_Api_Rest_Entity_Attachment') {
            throw new Carerix_Api_Rest_Exception('This method cannot be invoked on '.$get_called_class);
        }
        
        $entity = lcfirst(self::getEntityFromObject($get_called_class));
        if(!$this->getId()) {
            throw new Carerix_Api_Rest_Exception('Please load the object from the REST API first or set its id before calling this method.');
        }        
        $parameters = array_merge($parameters, array('entity' => $entity, 'id' => $this->getId()));
        $action = 'attachment';
        
        return self::$_manager->execute(
            'Carerix_Api_Rest_Entity_Attachment', 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate
        );
    }
    
    /**
     * Send an email.
     * 
     * @param array $parameters e.g. array('emailtemplate' => 'forgotpwd')
     * @param integer $hydrate [optional] hydration method 
     * @return mixed Carerix_Api_Rest_Collection of Carerix_Api_Rest_Entity_To_Do objects|array|raw
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @see http://development.wiki.carerix.com/index.php/Cxrest_API_methods#GET_.24object.2Femail
     */
    public function email(array $parameters, $hydrate = null)
    {
        $get_called_class = get_class($this);
        
        if($get_called_class == 'Carerix_Api_Rest_Entity_To_Do') {
            throw new Carerix_Api_Rest_Exception('This method cannot be invoked on '.$get_called_class);
        }
                
           $entity = lcfirst(self::getEntityFromObject($get_called_class));
        if(!$this->getId()) {
            throw new Carerix_Api_Rest_Exception('Please load the object from the REST API first or set its id before calling this method.');
        }              
        $parameters = array_merge($parameters, array('entity' => $entity, 'id' => $this->getId()));         
        $action = 'email';
        
        return self::$_manager->execute(
            'Carerix_Api_Rest_Entity_To_Do', 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate
        );
    }
    
    /**
     * Get object schema.
     * 
     * @param array $parameters [optional]
     * @param integer $hydrate [optional] hydration method 
     * @return mixed
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @see http://development.wiki.carerix.com/index.php/Cxrest_API_methods#GET_.24object.2Fdescribe
     */    
    public static function describe($parameters = null, $hydrate = self::HYDRATE_NONE)
    {
        $args = func_get_args();
        switch(count($args)) {
            case 1:
                if(!is_array($args[0])) {
                    $parameters = null;
                    $hydrate = $args[0];                    
                }
            break;
        }
                
        $get_called_class = get_called_class();
        if(!in_array($hydrate, array(self::HYDRATE_NONE, self::HYDRATE_ARRAY))) {
            throw new Carerix_Api_Rest_Exception('Unsupported hydration mode for '.__METHOD__);
        }
        return self::$_manager->execute(
            $get_called_class, 
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::OPTIONS, 
            $parameters,
            null,
            $hydrate
        );
    }    
    
    /**
     * Get object's Sencha Model.
     * 
     * @param array $parameters [optional]
     * @param integer $hydrate [optional] hydration method 
     * @return mixed
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @see http://cx.wiki.carerix.com/index.php/CxRest#Sencha_Models
     */    
    public static function sencha($parameters = null, $hydrate = self::HYDRATE_NONE)
    {
        $args = func_get_args();
        switch(count($args)) {
            case 1:
                if(!is_array($args[0])) {
                    $parameters = null;
                    $hydrate = $args[0];                    
                }
            break;
        }

        $action = 'sencha';
        $format = 'js';
        $get_called_class = get_called_class();
        
        if(!in_array($hydrate, array(self::HYDRATE_NONE, self::HYDRATE_ARRAY))) {
            throw new Carerix_Api_Rest_Exception('Unsupported hydration mode for '.__METHOD__);
        }
        return self::$_manager->execute(
            $get_called_class, 
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET, 
            $parameters,
            null,
            $hydrate
        );
    }    
    
    /**
     * Subscribe a contact person (user) or a candidate (employee) in your Carerix system to newsletters, groups or job alerts (except for user).
     * 
     * @param array $parameters [optional] e.g. array('x-cx-subscribe-mail' => 'web-subscribe')
     * @param integer $hydrate [optional] hydration method 
     * @return Carerix_Api_Rest_Entity_User|Carerix_Api_Rest_Entity_Employee
     */
    protected function subscribe($parameters = null, $hydrate = null)
    {
        $args = func_get_args();
        switch(count($args)) {
            case 1:
                if(!is_array($args[0])) {
                    $parameters = array();
                    $hydrate = $args[0];                    
                }
            break;
        }
                
        if(!$this->getId()) {
            throw new Carerix_Api_Rest_Exception('Please load the object from the REST API first or set id.');
        }

        $get_called_class = get_class($this);
        $action = 'subscribe';
        return self::$_manager->execute(
            $get_called_class, 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::PUT,
            null,
            null,
            $hydrate
        );        
    }
        
//    /**
//     * 
//     * Implements getBy magic method
//     * 
//     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
//     * @param string $method
//     * @param array $args
//     * @return array of 
//     */
//    public function __call($method, $args) {
//        if(substr($method, 0, 5) != 'getBy') {
//            return;
//        }
//
//        $method = substr($method, 5);
//        $qualifier = '';
//        $andParts = explode('And', $method);
//        
//        $qualifier .= implode(' AND ', self::argsToSql($args, $andParts));
//        
//        $orParts = explode('Or', $method);
//        $qualifier .= implode(' OR ', self::argsToSql($args, $orParts));
//        
//        return self::findAll(array('qualifier' => $qualifier));
//    }
    
    /**
     * Set attributes of this class.
     * 
     * @param array $values class attributes
     * @return self
     */
    public function fromArray(array $values) {
        $vars = get_object_vars($this);
        foreach($values as $k => $v) {
            if(!in_array($k, array_keys($vars))) {
                continue;
            }
            $this->{'set'.ucfirst($k)}($v);
        }        
        
        return $this;
    }
    
    /**
     * 
     * Initialize a new entity from array.
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @param array $array
     * @return Carerix_Api_Rest_Entity
     */
    public static function fromArrayStatic($array = array(), $class = null)
    {
        if(!is_array($array)) {
            return null;
        }
        if($class === null) {
            $class = get_called_class();
        }
        $vars = get_class_vars($class);
        $instance = new $class;

        $configuration = self::$_manager->getEntityConfiguration($class);
        $identifierKey = $configuration->getIdentifierKey();

        foreach($array as $k => $v) {
            if(!in_array($k, array_keys($vars))) {
                continue;
            }
            
            if(is_array($v)) {        
                if($k == 'attributes' && array_key_exists('id', $v)) {
                    $instance->{$identifierKey} = $v['id'];
                }                            
                $reflection = new ReflectionProperty($instance, $k);
                $association = self::getAssociationTarget($reflection);

                if(self::isOneToOneAssociation($reflection)) {                        
                    //go up one level
                    $v = array_shift($v);
                    $v = call_user_func($association.'::fromArrayStatic', $v, $association);
                }
                elseif(self::isOneToManyAssociation($reflection)) {
                    $collection = new Carerix_Api_Rest_Collection();
                    if(array_key_exists('attributes', $v) && array_key_exists('count', $v['attributes'])) {
                        $collection->setTotalCount($v['attributes']['count']);
                        unset($v['attributes']);
                        // go up one level                
                        $v = array_shift($v);
                        if(!is_array($v)) {
                            continue;
                        }
                        // count=1
                        if(!array_key_exists(0, $v)) {
                            $v = array($v);
                        }
                    }    
                            
                    if(is_array($v)) {            
                        foreach($v as $kk => $vv) {
                            $collection->append(call_user_func($association.'::fromArrayStatic', $vv, $association));
                        }
                    }
                    $v = $collection;
                }
            }        
            $instance->{$k} = $v;
            
        }
        return $instance;
    }
    
    /**
     * Hydrate php objects to array with non-null values only.
     * 
     * @param Carerix_Api_Rest_Entity $instance
     * @return array
     */
    public function toArray() {
        return self::toArrayStatic($this);
    }    
    
    /**
     * Hydrate php objects to array with non-null values only.
     * 
     * @param Carerix_Api_Rest_Entity $instance
     * @return array
     */
    public static function toArrayStatic($instance) {

        $vars = get_object_vars($instance);
        $class = get_class($instance);
        $array = array();
        foreach($vars as $k => $v) {
            if($v === null || (is_array($v) && empty($v))) {
                continue;
            }
            if(is_object($v)) {        
                echo $k, PHP_EOL;                
                $reflection = new ReflectionProperty($class, $k);
                $association = self::getAssociationTarget($reflection);
//                echo self::getVar($reflection, 'value-class');
                if(self::getVar($reflection, 'value-class')) {                        
                    
                }                
                else if(self::isOneToOneAssociation($reflection)) {                        
                    // convert one dimensional array to a value;
                    if(array_key_exists(0, $v)) {
                        $v = array_shift($v);
                    }
                    $v = call_user_func($association.'::toArrayStatic', $v);
                }
                elseif(self::isOneToManyAssociation($reflection)) {
                    $objects = array();
                    foreach($v as $kk => $vv) {
                        $objects[] = call_user_func($association.'::toArrayStatic', $vv);
                    }
                    $v = $objects;
                }
            }        
            $array[$k] = $v;
        }
        return $array;        
    }
    
    /**
     * Get var type
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @param ReflectionProperty $reflection
     * @param string $name
     * @return string
     */
    public static function getVar(ReflectionProperty $reflection, $name) {
        preg_match('/\* \@'.preg_quote($name).' (.*)$/siUum', $reflection->getDocComment(), $matches);
        if(array_key_exists(1, $matches)) {
            return $matches[1];
        }
        return false;        
    }
    
    /**
     * Check if property is an association.
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @param ReflectionProperty $reflection
     * @param string $type
     * @return boolean
     */
    public static function isAssociation(ReflectionProperty $reflection, $type = 'OneToOne') {
        return (boolean) preg_match('/@'.$type.'/i', $reflection->getDocComment());
    }
    
    /**
     * Check if property is one-to-one association.
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @param ReflectionProperty $reflection
     * @return boolean
     */
    public static function isOneToOneAssociation(ReflectionProperty $reflection) {
        return self::isAssociation($reflection, 'OneToOne');
    }
    
    /**
     * Check if property is one-to-many association.
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @param ReflectionProperty $reflection
     * @return boolean
     */
    public static function isOneToManyAssociation(ReflectionProperty $reflection) {
        return self::isAssociation($reflection, 'OneToMany');
    }
        
    /**
     * Get association target entity.
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     * @param ReflectionProperty $reflection
     * @return string|boolean string on success, false on failure
     */
    public static  function getAssociationTarget(ReflectionProperty $reflection) {
        preg_match('/targetEntity=\"([^\"]+)\"/i', $reflection->getDocComment(), $matches);
        if(array_key_exists(1, $matches)) {
            return $matches[1];
        }
        return false;
    }

    /**
     * Set id.
     * 
     * Alias for set$objectNameID() method.
     *
     * Provides a fluent interface.
     *
     * @param integer $id [optional]
     * @return self
     */
    public function setId($value)
    {
        $entity = self::getEntityFromObject($this);
        $identifierKey = Carerix_Api_Rest_EntityGenerator::getIdentifierKey($entity);

        $this->{$identifierKey} = $value;
        return $this;
    }

    /**
     * Set id.
     *
     * Alias for get$objectNameID() method. Provides a fluent interface.
     *
     * @return string
     */
    public function getId()
    {
        $entity = self::getEntityFromObject($this);
        $identifierKey = Carerix_Api_Rest_EntityGenerator::getIdentifierKey($entity);
        if(property_exists($this, $identifierKey)) {
            return $this->{$identifierKey};
        }
        return $this->attributes['id'];
    }    
    
    /**
     * @var array
     */
    public $attributes = null;
    
    /**
     * Set attributes
     * 
     * @param array $value
     * @return self
     */
    public function setAttributes($value)
    {
        $this->attributes = $value;
        return $this;
    }

    /**
     * Get attributes
     * 
     * @return array
     */
    public function getAttributes()
    {
        return $this->attributes;
    }

    /**
     * stableHash - unique record identifier in transient state, e.g. 348278036
     * @var integer
     */
    public $stableHash;
    
    /**
     * Gets stableHash
     *
     * @return integer
     */
    public function getStableHash() 
    {
        return $this->stableHash;
    }
    
    /**
     * Sets stableHash
     *
     * @param integer $stableHash stableHash
     * @return self
     */
    public function setStableHash($stableHash) 
    {
        $this->stableHash = $stableHash;
        return $this;
    }    
}

/**
 * Late static binding support for PHP 5.2
 * params in method on a called class should be declared on one line, e.g.
 * 
 * someCalledClass::get($p1, p2);
 * 
 * otherwise, the called class won't be detected. this is won't work
 * 
 * someCalledClass::get(
 *      $p1, 
 *      p2
 * );
 */
if(!function_exists('get_called_class')) {
    class class_tools {
        static $i = 0;
        static $fl = null;

        static function get_called_class() {
            $bt = debug_backtrace();

            if (self::$fl == $bt[2]['file'].$bt[2]['line']) {
                self::$i++;
            } else {
                self::$i = 0;
                self::$fl = $bt[2]['file'].$bt[2]['line'];
            }

            $lines = @file($bt[2]['file']);
            if($lines === false) {
                throw new Exception('Unable to determine get_called_class.');
            }

            preg_match_all('/([a-zA-Z0-9\_]+)::'.$bt[2]['function'].'/', $lines[$bt[2]['line']-1], $matches);

            return $matches[1][self::$i];
        }
    }

    function get_called_class() {
        return class_tools::get_called_class();
    }
}