<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:31:50 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Attachment extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $attachmentID = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 128
     */
    public $label = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $valid = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 0
     * @width
     */
    public $filePath = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $summary = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type d
     * @value-type-human
     */
    public $ranking = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 255
     */
    public $contentID = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_DataType_NSDictionary|array
     * @value-class NSDictionary
     * @allows-null 1
     */
    public $metaData = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toTypeNode
     * @qualifier ((typeID = 18) or (typeID = 0))
     * @default
     * @nodeType Document-type
     */
    public $toTypeNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Attachment_Data
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Attachment_Data")
     * @mandatory 0
     * @destination-entity CRAttachmentData
     * @to-many 0
     * @name toAttachmentData
     */
    public $toAttachmentData = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name owner
     */
    public $owner = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("attachmentID");
        $entityConfiguration->setName("attachment");
    }

    /**
     * Set attachmentID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setAttachmentID($value)
    {
        $this->attachmentID = $value;
        return $this;
    }

    /**
     * Get attachmentID.
     *
     * @return integer
     */
    public function getAttachmentID()
    {
        return $this->attachmentID;
    }

    /**
     * Set label.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setLabel($value)
    {
        $this->label = $value;
        return $this;
    }

    /**
     * Get label.
     *
     * @return string
     */
    public function getLabel()
    {
        return $this->label;
    }

    /**
     * Set valid.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setValid($value)
    {
        $this->valid = $value;
        return $this;
    }

    /**
     * Get valid.
     *
     * @return integer
     */
    public function getValid()
    {
        return $this->valid;
    }

    /**
     * Set filePath.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setFilePath($value)
    {
        $this->filePath = $value;
        return $this;
    }

    /**
     * Get filePath.
     *
     * @return string
     */
    public function getFilePath()
    {
        return $this->filePath;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set summary.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setSummary($value)
    {
        $this->summary = $value;
        return $this;
    }

    /**
     * Get summary.
     *
     * @return string
     */
    public function getSummary()
    {
        return $this->summary;
    }

    /**
     * Set ranking.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setRanking($value)
    {
        $this->ranking = $value;
        return $this;
    }

    /**
     * Get ranking.
     *
     * @return integer
     */
    public function getRanking()
    {
        return $this->ranking;
    }

    /**
     * Set contentID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setContentID($value)
    {
        $this->contentID = $value;
        return $this;
    }

    /**
     * Get contentID.
     *
     * @return string
     */
    public function getContentID()
    {
        return $this->contentID;
    }

    /**
     * Set metaData.
     *
     * Provides a fluent interface.
     *
     * @param Carerix_Api_Rest_DataType_NSDictionary|array $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setMetaData($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_DataType_NSDictionary($value);
        }
        $this->metaData = $value;
        return $this;
    }

    /**
     * Get metaData.
     *
     * @return Carerix_Api_Rest_DataType_NSDictionary|array
     */
    public function getMetaData()
    {
        return $this->metaData;
    }

    /**
     * Set toTypeNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setToTypeNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toTypeNode = $value;
        return $this;
    }

    /**
     * Get toTypeNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToTypeNode()
    {
        return $this->toTypeNode;
    }

    /**
     * Set toAttachmentData.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Attachment_Data $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setToAttachmentData($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Attachment_Data($value); 
        }                 
        $this->toAttachmentData = $value;
        return $this;
    }

    /**
     * Get toAttachmentData.
     *
     * @return Carerix_Api_Rest_Entity_Attachment_Data
     */
    public function getToAttachmentData()
    {
        return $this->toAttachmentData;
    }

    /**
     * Set owner.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_Attachment
     */
    public function setOwner($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->owner = $value;
        return $this;
    }

    /**
     * Get owner.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getOwner()
    {
        return $this->owner;
    }


}