<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:31:54 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Data_Node extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $dataNodeID = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $notActive = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $deleted = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isHidden = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isDefault = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $notes = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 100
     */
    public $exportCode = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isSystem = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Node_Type
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Node_Type")
     * @mandatory 1
     * @destination-entity CRNodeType
     * @to-many 0
     * @name type
     */
    public $type = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 1
     * @name childrenNodes
     */
    public $childrenNodes = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 1
     * @name parentNodes
     */
    public $parentNodes = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Data_Node_Value")
     * @mandatory 0
     * @destination-entity CRDataNodeValue
     * @to-many 1
     * @name values
     * @inverseName toDataNode
     */
    public $values = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("dataNodeID");
        $entityConfiguration->setName("data-node");
    }

    /**
     * Set dataNodeID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setDataNodeID($value)
    {
        $this->dataNodeID = $value;
        return $this;
    }

    /**
     * Get dataNodeID.
     *
     * @return integer
     */
    public function getDataNodeID()
    {
        return $this->dataNodeID;
    }

    /**
     * Set notActive.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setNotActive($value)
    {
        $this->notActive = $value;
        return $this;
    }

    /**
     * Get notActive.
     *
     * @return integer
     */
    public function getNotActive()
    {
        return $this->notActive;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set deleted.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setDeleted($value)
    {
        $this->deleted = $value;
        return $this;
    }

    /**
     * Get deleted.
     *
     * @return integer
     */
    public function getDeleted()
    {
        return $this->deleted;
    }

    /**
     * Set isHidden.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setIsHidden($value)
    {
        $this->isHidden = $value;
        return $this;
    }

    /**
     * Get isHidden.
     *
     * @return integer
     */
    public function getIsHidden()
    {
        return $this->isHidden;
    }

    /**
     * Set isDefault.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setIsDefault($value)
    {
        $this->isDefault = $value;
        return $this;
    }

    /**
     * Get isDefault.
     *
     * @return integer
     */
    public function getIsDefault()
    {
        return $this->isDefault;
    }

    /**
     * Set notes.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setNotes($value)
    {
        $this->notes = $value;
        return $this;
    }

    /**
     * Get notes.
     *
     * @return string
     */
    public function getNotes()
    {
        return $this->notes;
    }

    /**
     * Set exportCode.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setExportCode($value)
    {
        $this->exportCode = $value;
        return $this;
    }

    /**
     * Get exportCode.
     *
     * @return string
     */
    public function getExportCode()
    {
        return $this->exportCode;
    }

    /**
     * Set isSystem.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setIsSystem($value)
    {
        $this->isSystem = $value;
        return $this;
    }

    /**
     * Get isSystem.
     *
     * @return integer
     */
    public function getIsSystem()
    {
        return $this->isSystem;
    }

    /**
     * Set type.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Node_Type $value
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setType($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Node_Type($value); 
        }                 
        $this->type = $value;
        return $this;
    }

    /**
     * Get type.
     *
     * @return Carerix_Api_Rest_Entity_Node_Type
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * Set childrenNodes.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setChildrenNodes($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->childrenNodes = $values;
        return $this;
    }

    /**
     * Get childrenNodes.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Data_Node
     */
    public function getChildrenNodes($index = null)
    {
        if($index !== null) {
            return $this->childrenNodes[$index];
        }
        return $this->childrenNodes;
    }

    /**
     * Set parentNodes.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setParentNodes($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->parentNodes = $values;
        return $this;
    }

    /**
     * Get parentNodes.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Data_Node
     */
    public function getParentNodes($index = null)
    {
        if($index !== null) {
            return $this->parentNodes[$index];
        }
        return $this->parentNodes;
    }

    /**
     * Set values.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Data_Node
     */
    public function setValues($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->values = $values;
        return $this;
    }

    /**
     * Get values.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Data_Node_Value
     */
    public function getValues($index = null)
    {
        if($index !== null) {
            return $this->values[$index];
        }
        return $this->values;
    }


}