<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:31:56 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Email_Address extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 200
     */
    public $emailAddress = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $emailAddressID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $invalid = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name toUser
     */
    public $toUser = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toEmailAddressLabel
     * @qualifier ((typeID = 161) or (typeID = 0))
     * @default
     * @nodeType E-mailadres-label
     */
    public $toEmailAddressLabel = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("emailAddressID");
        $entityConfiguration->setName("email-address");
    }

    /**
     * Set emailAddress.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setEmailAddress($value)
    {
        $this->emailAddress = $value;
        return $this;
    }

    /**
     * Get emailAddress.
     *
     * @return string
     */
    public function getEmailAddress()
    {
        return $this->emailAddress;
    }

    /**
     * Set emailAddressID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setEmailAddressID($value)
    {
        $this->emailAddressID = $value;
        return $this;
    }

    /**
     * Get emailAddressID.
     *
     * @return integer
     */
    public function getEmailAddressID()
    {
        return $this->emailAddressID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set invalid.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setInvalid($value)
    {
        $this->invalid = $value;
        return $this;
    }

    /**
     * Get invalid.
     *
     * @return integer
     */
    public function getInvalid()
    {
        return $this->invalid;
    }

    /**
     * Set toUser.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setToUser($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->toUser = $value;
        return $this;
    }

    /**
     * Get toUser.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getToUser()
    {
        return $this->toUser;
    }

    /**
     * Set toEmailAddressLabel.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Email_Address
     */
    public function setToEmailAddressLabel($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toEmailAddressLabel = $value;
        return $this;
    }

    /**
     * Get toEmailAddressLabel.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToEmailAddressLabel()
    {
        return $this->toEmailAddressLabel;
    }


}