<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:00 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Employee_Language extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $employeeLanguageID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Employee
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Employee")
     * @mandatory 0
     * @destination-entity CREmployee
     * @to-many 0
     * @name toEmployee
     */
    public $toEmployee = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toLanguageSpeakLevel
     * @qualifier ((typeID = 32) or (typeID = 0))
     * @default
     * @nodeType Taalvaardigheid
     */
    public $toLanguageSpeakLevel = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toLanguageReadLevel
     * @qualifier ((typeID = 32) or (typeID = 0))
     * @default
     * @nodeType Taalvaardigheid
     */
    public $toLanguageReadLevel = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toLanguageWriteLevel
     * @qualifier ((typeID = 32) or (typeID = 0))
     * @default
     * @nodeType Taalvaardigheid
     */
    public $toLanguageWriteLevel = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toLanguage
     * @qualifier ((typeID = 31) or (typeID = 0))
     * @default
     * @nodeType Taal
     */
    public $toLanguage = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("employeeLanguageID");
        $entityConfiguration->setName("employee-language");
    }

    /**
     * Set employeeLanguageID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setEmployeeLanguageID($value)
    {
        $this->employeeLanguageID = $value;
        return $this;
    }

    /**
     * Get employeeLanguageID.
     *
     * @return integer
     */
    public function getEmployeeLanguageID()
    {
        return $this->employeeLanguageID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set toEmployee.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Employee $value
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setToEmployee($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Employee($value); 
        }                 
        $this->toEmployee = $value;
        return $this;
    }

    /**
     * Get toEmployee.
     *
     * @return Carerix_Api_Rest_Entity_Employee
     */
    public function getToEmployee()
    {
        return $this->toEmployee;
    }

    /**
     * Set toLanguageSpeakLevel.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setToLanguageSpeakLevel($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toLanguageSpeakLevel = $value;
        return $this;
    }

    /**
     * Get toLanguageSpeakLevel.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToLanguageSpeakLevel()
    {
        return $this->toLanguageSpeakLevel;
    }

    /**
     * Set toLanguageReadLevel.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setToLanguageReadLevel($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toLanguageReadLevel = $value;
        return $this;
    }

    /**
     * Get toLanguageReadLevel.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToLanguageReadLevel()
    {
        return $this->toLanguageReadLevel;
    }

    /**
     * Set toLanguageWriteLevel.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setToLanguageWriteLevel($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toLanguageWriteLevel = $value;
        return $this;
    }

    /**
     * Get toLanguageWriteLevel.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToLanguageWriteLevel()
    {
        return $this->toLanguageWriteLevel;
    }

    /**
     * Set toLanguage.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Employee_Language
     */
    public function setToLanguage($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toLanguage = $value;
        return $this;
    }

    /**
     * Get toLanguage.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToLanguage()
    {
        return $this->toLanguage;
    }


}