<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:02 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Finance extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $deleted = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $endDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 100
     */
    public $info = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $financeID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $startDate = null;

    /**
     * @access private
     * @var float
     * @value-class NSDecimalNumber
     * @allows-null 1
     */
    public $amount = null;

    /**
     * @access private
     * @var float
     * @value-class NSDecimalNumber
     * @allows-null 1
     */
    public $tariff = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $noInvoice = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $sortOrder = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Node_Type
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Node_Type")
     * @mandatory 0
     * @destination-entity CRNodeType
     * @to-many 0
     * @name toTypeNode
     */
    public $toTypeNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toStatusNode
     */
    public $toStatusNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toKindNode
     * @default
     * @nodeType ${toTypeNode.name}
     */
    public $toKindNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toCurrencyNode
     * @qualifier ((typeID = 84) or (typeID = 0))
     * @default
     * @nodeType Valuta
     */
    public $toCurrencyNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toUnitNode
     * @default
     * @nodeType ${toTypeNode.name}-eenheid
     */
    public $toUnitNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Resource
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Resource")
     * @mandatory 0
     * @destination-entity CRResource
     * @to-many 0
     * @name toResource
     */
    public $toResource = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("financeID");
        $entityConfiguration->setName("finance");
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set deleted.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setDeleted($value)
    {
        $this->deleted = $value;
        return $this;
    }

    /**
     * Get deleted.
     *
     * @return integer
     */
    public function getDeleted()
    {
        return $this->deleted;
    }

    /**
     * Set endDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setEndDate($value)
    {
        $this->endDate = $value;
        return $this;
    }

    /**
     * Get endDate.
     *
     * @return string
     */
    public function getEndDate()
    {
        return $this->endDate;
    }

    /**
     * Set info.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setInfo($value)
    {
        $this->info = $value;
        return $this;
    }

    /**
     * Get info.
     *
     * @return string
     */
    public function getInfo()
    {
        return $this->info;
    }

    /**
     * Set financeID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setFinanceID($value)
    {
        $this->financeID = $value;
        return $this;
    }

    /**
     * Get financeID.
     *
     * @return integer
     */
    public function getFinanceID()
    {
        return $this->financeID;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set startDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setStartDate($value)
    {
        $this->startDate = $value;
        return $this;
    }

    /**
     * Get startDate.
     *
     * @return string
     */
    public function getStartDate()
    {
        return $this->startDate;
    }

    /**
     * Set amount.
     *
     * Provides a fluent interface.
     *
     * @param float $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setAmount($value)
    {
        $this->amount = $value;
        return $this;
    }

    /**
     * Get amount.
     *
     * @return float
     */
    public function getAmount()
    {
        return $this->amount;
    }

    /**
     * Set tariff.
     *
     * Provides a fluent interface.
     *
     * @param float $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setTariff($value)
    {
        $this->tariff = $value;
        return $this;
    }

    /**
     * Get tariff.
     *
     * @return float
     */
    public function getTariff()
    {
        return $this->tariff;
    }

    /**
     * Set noInvoice.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setNoInvoice($value)
    {
        $this->noInvoice = $value;
        return $this;
    }

    /**
     * Get noInvoice.
     *
     * @return integer
     */
    public function getNoInvoice()
    {
        return $this->noInvoice;
    }

    /**
     * Set sortOrder.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setSortOrder($value)
    {
        $this->sortOrder = $value;
        return $this;
    }

    /**
     * Get sortOrder.
     *
     * @return integer
     */
    public function getSortOrder()
    {
        return $this->sortOrder;
    }

    /**
     * Set toTypeNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Node_Type $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setToTypeNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Node_Type($value); 
        }                 
        $this->toTypeNode = $value;
        return $this;
    }

    /**
     * Get toTypeNode.
     *
     * @return Carerix_Api_Rest_Entity_Node_Type
     */
    public function getToTypeNode()
    {
        return $this->toTypeNode;
    }

    /**
     * Set toStatusNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setToStatusNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toStatusNode = $value;
        return $this;
    }

    /**
     * Get toStatusNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToStatusNode()
    {
        return $this->toStatusNode;
    }

    /**
     * Set toKindNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setToKindNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toKindNode = $value;
        return $this;
    }

    /**
     * Get toKindNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToKindNode()
    {
        return $this->toKindNode;
    }

    /**
     * Set toCurrencyNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setToCurrencyNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toCurrencyNode = $value;
        return $this;
    }

    /**
     * Get toCurrencyNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToCurrencyNode()
    {
        return $this->toCurrencyNode;
    }

    /**
     * Set toUnitNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setToUnitNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toUnitNode = $value;
        return $this;
    }

    /**
     * Get toUnitNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToUnitNode()
    {
        return $this->toUnitNode;
    }

    /**
     * Set toResource.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Resource $value
     * @return Carerix_Api_Rest_Entity_Abstract_Finance
     */
    public function setToResource($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Resource($value); 
        }                 
        $this->toResource = $value;
        return $this;
    }

    /**
     * Get toResource.
     *
     * @return Carerix_Api_Rest_Entity_Resource
     */
    public function getToResource()
    {
        return $this->toResource;
    }


}