<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:09 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Resource extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $resourceID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 100
     */
    public $name = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $deleted = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $location = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $resourceDescription = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $notes = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000
     */
    public $locationUrl = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000
     */
    public $url = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isActive = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000
     */
    public $identification = null;

    /**
     * @access private
     * @var float
     * @value-class NSDecimalNumber
     * @allows-null 1
     */
    public $amount = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Attachment")
     * @mandatory 0
     * @destination-entity CRAttachment
     * @to-many 1
     * @name attachments
     */
    public $attachments = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name createdBy
     */
    public $createdBy = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name modifiedBy
     */
    public $modifiedBy = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name owner
     */
    public $owner = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toResourceTypeNode
     */
    public $toResourceTypeNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toRegulationTypeNode
     */
    public $toRegulationTypeNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toAmountCurrencyNode
     */
    public $toAmountCurrencyNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Agency
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Agency")
     * @mandatory 0
     * @destination-entity CRAgency
     * @to-many 0
     * @name agency
     */
    public $agency = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("resourceID");
        $entityConfiguration->setName("resource");
    }

    /**
     * Set resourceID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setResourceID($value)
    {
        $this->resourceID = $value;
        return $this;
    }

    /**
     * Get resourceID.
     *
     * @return integer
     */
    public function getResourceID()
    {
        return $this->resourceID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set name.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setName($value)
    {
        $this->name = $value;
        return $this;
    }

    /**
     * Get name.
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set deleted.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setDeleted($value)
    {
        $this->deleted = $value;
        return $this;
    }

    /**
     * Get deleted.
     *
     * @return integer
     */
    public function getDeleted()
    {
        return $this->deleted;
    }

    /**
     * Set location.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setLocation($value)
    {
        $this->location = $value;
        return $this;
    }

    /**
     * Get location.
     *
     * @return string
     */
    public function getLocation()
    {
        return $this->location;
    }

    /**
     * Set resourceDescription.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setResourceDescription($value)
    {
        $this->resourceDescription = $value;
        return $this;
    }

    /**
     * Get resourceDescription.
     *
     * @return string
     */
    public function getResourceDescription()
    {
        return $this->resourceDescription;
    }

    /**
     * Set notes.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setNotes($value)
    {
        $this->notes = $value;
        return $this;
    }

    /**
     * Get notes.
     *
     * @return string
     */
    public function getNotes()
    {
        return $this->notes;
    }

    /**
     * Set locationUrl.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setLocationUrl($value)
    {
        $this->locationUrl = $value;
        return $this;
    }

    /**
     * Get locationUrl.
     *
     * @return string
     */
    public function getLocationUrl()
    {
        return $this->locationUrl;
    }

    /**
     * Set url.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setUrl($value)
    {
        $this->url = $value;
        return $this;
    }

    /**
     * Get url.
     *
     * @return string
     */
    public function getUrl()
    {
        return $this->url;
    }

    /**
     * Set isActive.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setIsActive($value)
    {
        $this->isActive = $value;
        return $this;
    }

    /**
     * Get isActive.
     *
     * @return integer
     */
    public function getIsActive()
    {
        return $this->isActive;
    }

    /**
     * Set identification.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setIdentification($value)
    {
        $this->identification = $value;
        return $this;
    }

    /**
     * Get identification.
     *
     * @return string
     */
    public function getIdentification()
    {
        return $this->identification;
    }

    /**
     * Set amount.
     *
     * Provides a fluent interface.
     *
     * @param float $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setAmount($value)
    {
        $this->amount = $value;
        return $this;
    }

    /**
     * Get amount.
     *
     * @return float
     */
    public function getAmount()
    {
        return $this->amount;
    }

    /**
     * Set attachments.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setAttachments($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->attachments = $values;
        return $this;
    }

    /**
     * Get attachments.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Attachment
     */
    public function getAttachments($index = null)
    {
        if($index !== null) {
            return $this->attachments[$index];
        }
        return $this->attachments;
    }

    /**
     * Set createdBy.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setCreatedBy($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->createdBy = $value;
        return $this;
    }

    /**
     * Get createdBy.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getCreatedBy()
    {
        return $this->createdBy;
    }

    /**
     * Set modifiedBy.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setModifiedBy($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->modifiedBy = $value;
        return $this;
    }

    /**
     * Get modifiedBy.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getModifiedBy()
    {
        return $this->modifiedBy;
    }

    /**
     * Set owner.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setOwner($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->owner = $value;
        return $this;
    }

    /**
     * Get owner.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getOwner()
    {
        return $this->owner;
    }

    /**
     * Set toResourceTypeNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setToResourceTypeNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toResourceTypeNode = $value;
        return $this;
    }

    /**
     * Get toResourceTypeNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToResourceTypeNode()
    {
        return $this->toResourceTypeNode;
    }

    /**
     * Set toRegulationTypeNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setToRegulationTypeNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toRegulationTypeNode = $value;
        return $this;
    }

    /**
     * Get toRegulationTypeNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToRegulationTypeNode()
    {
        return $this->toRegulationTypeNode;
    }

    /**
     * Set toAmountCurrencyNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setToAmountCurrencyNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toAmountCurrencyNode = $value;
        return $this;
    }

    /**
     * Get toAmountCurrencyNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToAmountCurrencyNode()
    {
        return $this->toAmountCurrencyNode;
    }

    /**
     * Set agency.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Agency $value
     * @return Carerix_Api_Rest_Entity_Abstract_Resource
     */
    public function setAgency($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Agency($value); 
        }                 
        $this->agency = $value;
        return $this;
    }

    /**
     * Get agency.
     *
     * @return Carerix_Api_Rest_Entity_Agency
     */
    public function getAgency()
    {
        return $this->agency;
    }


}