<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:10 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Status_Info extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isFinal = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 20
     */
    public $statusName = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 200
     */
    public $displayName = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $statusValue = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $statusInfoID = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 20
     */
    public $indicationColor = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 1
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $sortOrder = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $notActive = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isDefault = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isJobDefault = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000000
     */
    public $notes = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 32
     */
    public $statusGroupID = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Template_Reference")
     * @mandatory 0
     * @destination-entity CRTemplateReference
     * @to-many 1
     * @name templateReferences
     */
    public $templateReferences = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Email_Template")
     * @mandatory 0
     * @destination-entity CREmailTemplate
     * @to-many 1
     * @name emailTemplates
     */
    public $emailTemplates = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toProductGroupNode
     * @qualifier ((typeID = 24) or (typeID = 0))
     * @default
     * @nodeType Productgroep
     */
    public $toProductGroupNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Status_Info_Link")
     * @mandatory 0
     * @destination-entity CRStatusInfoLink
     * @to-many 1
     * @name parentLinks
     */
    public $parentLinks = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Status_Info")
     * @mandatory 0
     * @destination-entity CRStatusInfo
     * @to-many 1
     * @name parents
     */
    public $parents = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Status_Info")
     * @mandatory 0
     * @destination-entity CRStatusInfo
     * @to-many 1
     * @name children
     */
    public $children = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("statusInfoID");
        $entityConfiguration->setName("status-info");
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set isFinal.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setIsFinal($value)
    {
        $this->isFinal = $value;
        return $this;
    }

    /**
     * Get isFinal.
     *
     * @return integer
     */
    public function getIsFinal()
    {
        return $this->isFinal;
    }

    /**
     * Set statusName.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setStatusName($value)
    {
        $this->statusName = $value;
        return $this;
    }

    /**
     * Get statusName.
     *
     * @return string
     */
    public function getStatusName()
    {
        return $this->statusName;
    }

    /**
     * Set displayName.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setDisplayName($value)
    {
        $this->displayName = $value;
        return $this;
    }

    /**
     * Get displayName.
     *
     * @return string
     */
    public function getDisplayName()
    {
        return $this->displayName;
    }

    /**
     * Set statusValue.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setStatusValue($value)
    {
        $this->statusValue = $value;
        return $this;
    }

    /**
     * Get statusValue.
     *
     * @return integer
     */
    public function getStatusValue()
    {
        return $this->statusValue;
    }

    /**
     * Set statusInfoID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setStatusInfoID($value)
    {
        $this->statusInfoID = $value;
        return $this;
    }

    /**
     * Get statusInfoID.
     *
     * @return integer
     */
    public function getStatusInfoID()
    {
        return $this->statusInfoID;
    }

    /**
     * Set indicationColor.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setIndicationColor($value)
    {
        $this->indicationColor = $value;
        return $this;
    }

    /**
     * Get indicationColor.
     *
     * @return string
     */
    public function getIndicationColor()
    {
        return $this->indicationColor;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set sortOrder.
     *
     * Provides a fluent interface.
     *
     * @param integer $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setSortOrder($value)
    {
        $this->sortOrder = $value;
        return $this;
    }

    /**
     * Get sortOrder.
     *
     * @return integer
     */
    public function getSortOrder()
    {
        return $this->sortOrder;
    }

    /**
     * Set notActive.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setNotActive($value)
    {
        $this->notActive = $value;
        return $this;
    }

    /**
     * Get notActive.
     *
     * @return integer
     */
    public function getNotActive()
    {
        return $this->notActive;
    }

    /**
     * Set isDefault.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setIsDefault($value)
    {
        $this->isDefault = $value;
        return $this;
    }

    /**
     * Get isDefault.
     *
     * @return integer
     */
    public function getIsDefault()
    {
        return $this->isDefault;
    }

    /**
     * Set isJobDefault.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setIsJobDefault($value)
    {
        $this->isJobDefault = $value;
        return $this;
    }

    /**
     * Get isJobDefault.
     *
     * @return integer
     */
    public function getIsJobDefault()
    {
        return $this->isJobDefault;
    }

    /**
     * Set notes.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setNotes($value)
    {
        $this->notes = $value;
        return $this;
    }

    /**
     * Get notes.
     *
     * @return string
     */
    public function getNotes()
    {
        return $this->notes;
    }

    /**
     * Set statusGroupID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setStatusGroupID($value)
    {
        $this->statusGroupID = $value;
        return $this;
    }

    /**
     * Get statusGroupID.
     *
     * @return string
     */
    public function getStatusGroupID()
    {
        return $this->statusGroupID;
    }

    /**
     * Set templateReferences.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setTemplateReferences($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->templateReferences = $values;
        return $this;
    }

    /**
     * Get templateReferences.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Template_Reference
     */
    public function getTemplateReferences($index = null)
    {
        if($index !== null) {
            return $this->templateReferences[$index];
        }
        return $this->templateReferences;
    }

    /**
     * Set emailTemplates.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setEmailTemplates($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->emailTemplates = $values;
        return $this;
    }

    /**
     * Get emailTemplates.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Email_Template
     */
    public function getEmailTemplates($index = null)
    {
        if($index !== null) {
            return $this->emailTemplates[$index];
        }
        return $this->emailTemplates;
    }

    /**
     * Set toProductGroupNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setToProductGroupNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toProductGroupNode = $value;
        return $this;
    }

    /**
     * Get toProductGroupNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToProductGroupNode()
    {
        return $this->toProductGroupNode;
    }

    /**
     * Set parentLinks.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setParentLinks($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->parentLinks = $values;
        return $this;
    }

    /**
     * Get parentLinks.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Status_Info_Link
     */
    public function getParentLinks($index = null)
    {
        if($index !== null) {
            return $this->parentLinks[$index];
        }
        return $this->parentLinks;
    }

    /**
     * Set parents.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setParents($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->parents = $values;
        return $this;
    }

    /**
     * Get parents.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Status_Info
     */
    public function getParents($index = null)
    {
        if($index !== null) {
            return $this->parents[$index];
        }
        return $this->parents;
    }

    /**
     * Set children.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Status_Info
     */
    public function setChildren($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->children = $values;
        return $this;
    }

    /**
     * Get children.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Status_Info
     */
    public function getChildren($index = null)
    {
        if($index !== null) {
            return $this->children[$index];
        }
        return $this->children;
    }


}