<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:12 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_To_Do_User extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $processDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isActive = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $emailAddressKey = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name toUser
     */
    public $toUser = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_To_Do
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_To_Do")
     * @mandatory 0
     * @destination-entity CRToDo
     * @to-many 0
     * @name toToDo
     * @qualifier (todoTypeKey = 22)
     * @inverseName toDoUsers
     */
    public $toToDo = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Employee
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Employee")
     * @mandatory 0
     * @destination-entity CREmployee
     * @to-many 0
     * @name toEmployee
     */
    public $toEmployee = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toStatusNode
     * @qualifier ((typeID = 190) or (typeID = 0))
     * @default
     * @nodeType Deelnemer-status
     */
    public $toStatusNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toRoleNode
     */
    public $toRoleNode = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("toDoUserID");
        $entityConfiguration->setName("to-do-user");
    }

    /**
     * Set processDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setProcessDate($value)
    {
        $this->processDate = $value;
        return $this;
    }

    /**
     * Get processDate.
     *
     * @return string
     */
    public function getProcessDate()
    {
        return $this->processDate;
    }

    /**
     * Set isActive.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setIsActive($value)
    {
        $this->isActive = $value;
        return $this;
    }

    /**
     * Get isActive.
     *
     * @return integer
     */
    public function getIsActive()
    {
        return $this->isActive;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set emailAddressKey.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setEmailAddressKey($value)
    {
        $this->emailAddressKey = $value;
        return $this;
    }

    /**
     * Get emailAddressKey.
     *
     * @return integer
     */
    public function getEmailAddressKey()
    {
        return $this->emailAddressKey;
    }

    /**
     * Set toUser.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setToUser($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->toUser = $value;
        return $this;
    }

    /**
     * Get toUser.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getToUser()
    {
        return $this->toUser;
    }

    /**
     * Set toToDo.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_To_Do $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setToToDo($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_To_Do($value); 
        }                 
        $this->toToDo = $value;
        return $this;
    }

    /**
     * Get toToDo.
     *
     * @return Carerix_Api_Rest_Entity_To_Do
     */
    public function getToToDo()
    {
        return $this->toToDo;
    }

    /**
     * Set toEmployee.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Employee $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setToEmployee($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Employee($value); 
        }                 
        $this->toEmployee = $value;
        return $this;
    }

    /**
     * Get toEmployee.
     *
     * @return Carerix_Api_Rest_Entity_Employee
     */
    public function getToEmployee()
    {
        return $this->toEmployee;
    }

    /**
     * Set toStatusNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setToStatusNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toStatusNode = $value;
        return $this;
    }

    /**
     * Get toStatusNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToStatusNode()
    {
        return $this->toStatusNode;
    }

    /**
     * Set toRoleNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_To_Do_User
     */
    public function setToRoleNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toRoleNode = $value;
        return $this;
    }

    /**
     * Get toRoleNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToRoleNode()
    {
        return $this->toRoleNode;
    }


}