<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:14 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Url extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 1000
     */
    public $url = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $urlID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 0
     * @destination-entity CRUser
     * @to-many 0
     * @name toUser
     */
    public $toUser = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toUrlLabel
     */
    public $toUrlLabel = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("urlID");
        $entityConfiguration->setName("url");
    }

    /**
     * Set url.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Url
     */
    public function setUrl($value)
    {
        $this->url = $value;
        return $this;
    }

    /**
     * Get url.
     *
     * @return string
     */
    public function getUrl()
    {
        return $this->url;
    }

    /**
     * Set urlID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Url
     */
    public function setUrlID($value)
    {
        $this->urlID = $value;
        return $this;
    }

    /**
     * Get urlID.
     *
     * @return integer
     */
    public function getUrlID()
    {
        return $this->urlID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Url
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Url
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set toUser.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_Url
     */
    public function setToUser($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->toUser = $value;
        return $this;
    }

    /**
     * Get toUser.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getToUser()
    {
        return $this->toUser;
    }

    /**
     * Set toUrlLabel.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Url
     */
    public function setToUrlLabel($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toUrlLabel = $value;
        return $this;
    }

    /**
     * Get toUrlLabel.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToUrlLabel()
    {
        return $this->toUrlLabel;
    }


}