<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:15 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_User_Company extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 16
     * @isUnique 1
     */
    public $importID = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Company
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Company")
     * @mandatory 1
     * @destination-entity CRCompany
     * @to-many 0
     * @name toCompany
     */
    public $toCompany = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_User
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_User")
     * @mandatory 1
     * @destination-entity CRUser
     * @to-many 0
     * @name toUser
     */
    public $toUser = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toRelationshipNode
     */
    public $toRelationshipNode = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("userCompanyID");
        $entityConfiguration->setName("user-company");
    }

    /**
     * Set importID.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_User_Company
     */
    public function setImportID($value)
    {
        $this->importID = $value;
        return $this;
    }

    /**
     * Get importID.
     *
     * @return string
     */
    public function getImportID()
    {
        return $this->importID;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_User_Company
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set toCompany.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Company $value
     * @return Carerix_Api_Rest_Entity_Abstract_User_Company
     */
    public function setToCompany($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Company($value); 
        }                 
        $this->toCompany = $value;
        return $this;
    }

    /**
     * Get toCompany.
     *
     * @return Carerix_Api_Rest_Entity_Company
     */
    public function getToCompany()
    {
        return $this->toCompany;
    }

    /**
     * Set toUser.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_User $value
     * @return Carerix_Api_Rest_Entity_Abstract_User_Company
     */
    public function setToUser($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_User($value); 
        }                 
        $this->toUser = $value;
        return $this;
    }

    /**
     * Get toUser.
     *
     * @return Carerix_Api_Rest_Entity_User
     */
    public function getToUser()
    {
        return $this->toUser;
    }

    /**
     * Set toRelationshipNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_User_Company
     */
    public function setToRelationshipNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toRelationshipNode = $value;
        return $this;
    }

    /**
     * Get toRelationshipNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToRelationshipNode()
    {
        return $this->toRelationshipNode;
    }


}