<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:19 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Week_Hour extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $deleted = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $weekHourID = null;

    /**
     * @access private
     * @var string
     * @value-class NSString
     * @allows-null 1
     * @width 200
     */
    public $info = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 1
     */
    public $weekMondayDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type s
     * @value-type-human short integer (16 bits)
     */
    public $isPlanning = null;

    /**
     * @access private
     * @var float
     * @value-class NSDecimalNumber
     * @allows-null 1
     */
    public $approvedTotal = null;

    /**
     * @access private
     * @var float
     * @value-class NSDecimalNumber
     * @allows-null 1
     */
    public $invoicedTotal = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Hour")
     * @mandatory 0
     * @destination-entity CRHour
     * @to-many 1
     * @name hoursUnsorted
     */
    public $hoursUnsorted = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toHourTypeNode
     * @qualifier ((typeID = 21) or (typeID = 0))
     * @default
     * @nodeType Declaratiesoort
     */
    public $toHourTypeNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Job
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Job")
     * @mandatory 0
     * @destination-entity CRJob
     * @to-many 0
     * @name toJob
     */
    public $toJob = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Employee
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Employee")
     * @mandatory 0
     * @destination-entity CREmployee
     * @to-many 0
     * @name toEmployee
     */
    public $toEmployee = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Data_Node
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Data_Node")
     * @mandatory 0
     * @destination-entity CRDataNode
     * @to-many 0
     * @name toStatusNode
     * @qualifier ((typeID = 20) or (typeID = 0))
     * @default
     * @nodeType Weekstaat-status
     */
    public $toStatusNode = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Week_Hour_View
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Week_Hour_View")
     * @mandatory 0
     * @destination-entity CRWeekHourView
     * @to-many 0
     * @name toWeekHourView
     */
    public $toWeekHourView = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Week_Hour_Job_View
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Week_Hour_Job_View")
     * @mandatory 0
     * @destination-entity CRWeekHourJobView
     * @to-many 0
     * @name toWeekHourJobView
     */
    public $toWeekHourJobView = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Invoice_Line")
     * @mandatory 0
     * @destination-entity CRInvoiceLine
     * @to-many 1
     * @name invoiceLines
     */
    public $invoiceLines = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("weekHourID");
        $entityConfiguration->setName("week-hour");
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set deleted.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setDeleted($value)
    {
        $this->deleted = $value;
        return $this;
    }

    /**
     * Get deleted.
     *
     * @return integer
     */
    public function getDeleted()
    {
        return $this->deleted;
    }

    /**
     * Set weekHourID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setWeekHourID($value)
    {
        $this->weekHourID = $value;
        return $this;
    }

    /**
     * Get weekHourID.
     *
     * @return integer
     */
    public function getWeekHourID()
    {
        return $this->weekHourID;
    }

    /**
     * Set info.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setInfo($value)
    {
        $this->info = $value;
        return $this;
    }

    /**
     * Get info.
     *
     * @return string
     */
    public function getInfo()
    {
        return $this->info;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set weekMondayDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setWeekMondayDate($value)
    {
        $this->weekMondayDate = $value;
        return $this;
    }

    /**
     * Get weekMondayDate.
     *
     * @return string
     */
    public function getWeekMondayDate()
    {
        return $this->weekMondayDate;
    }

    /**
     * Set isPlanning.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setIsPlanning($value)
    {
        $this->isPlanning = $value;
        return $this;
    }

    /**
     * Get isPlanning.
     *
     * @return integer
     */
    public function getIsPlanning()
    {
        return $this->isPlanning;
    }

    /**
     * Set approvedTotal.
     *
     * Provides a fluent interface.
     *
     * @param float $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setApprovedTotal($value)
    {
        $this->approvedTotal = $value;
        return $this;
    }

    /**
     * Get approvedTotal.
     *
     * @return float
     */
    public function getApprovedTotal()
    {
        return $this->approvedTotal;
    }

    /**
     * Set invoicedTotal.
     *
     * Provides a fluent interface.
     *
     * @param float $value [optional]
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setInvoicedTotal($value)
    {
        $this->invoicedTotal = $value;
        return $this;
    }

    /**
     * Get invoicedTotal.
     *
     * @return float
     */
    public function getInvoicedTotal()
    {
        return $this->invoicedTotal;
    }

    /**
     * Set hoursUnsorted.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setHoursUnsorted($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->hoursUnsorted = $values;
        return $this;
    }

    /**
     * Get hoursUnsorted.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Hour
     */
    public function getHoursUnsorted($index = null)
    {
        if($index !== null) {
            return $this->hoursUnsorted[$index];
        }
        return $this->hoursUnsorted;
    }

    /**
     * Set toHourTypeNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setToHourTypeNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toHourTypeNode = $value;
        return $this;
    }

    /**
     * Get toHourTypeNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToHourTypeNode()
    {
        return $this->toHourTypeNode;
    }

    /**
     * Set toJob.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Job $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setToJob($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Job($value); 
        }                 
        $this->toJob = $value;
        return $this;
    }

    /**
     * Get toJob.
     *
     * @return Carerix_Api_Rest_Entity_Job
     */
    public function getToJob()
    {
        return $this->toJob;
    }

    /**
     * Set toEmployee.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Employee $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setToEmployee($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Employee($value); 
        }                 
        $this->toEmployee = $value;
        return $this;
    }

    /**
     * Get toEmployee.
     *
     * @return Carerix_Api_Rest_Entity_Employee
     */
    public function getToEmployee()
    {
        return $this->toEmployee;
    }

    /**
     * Set toStatusNode.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Data_Node $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setToStatusNode($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Data_Node($value); 
        }                 
        $this->toStatusNode = $value;
        return $this;
    }

    /**
     * Get toStatusNode.
     *
     * @return Carerix_Api_Rest_Entity_Data_Node
     */
    public function getToStatusNode()
    {
        return $this->toStatusNode;
    }

    /**
     * Set toWeekHourView.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Week_Hour_View $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setToWeekHourView($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Week_Hour_View($value); 
        }                 
        $this->toWeekHourView = $value;
        return $this;
    }

    /**
     * Get toWeekHourView.
     *
     * @return Carerix_Api_Rest_Entity_Week_Hour_View
     */
    public function getToWeekHourView()
    {
        return $this->toWeekHourView;
    }

    /**
     * Set toWeekHourJobView.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Week_Hour_Job_View $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setToWeekHourJobView($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Week_Hour_Job_View($value); 
        }                 
        $this->toWeekHourJobView = $value;
        return $this;
    }

    /**
     * Get toWeekHourJobView.
     *
     * @return Carerix_Api_Rest_Entity_Week_Hour_Job_View
     */
    public function getToWeekHourJobView()
    {
        return $this->toWeekHourJobView;
    }

    /**
     * Set invoiceLines.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour
     */
    public function setInvoiceLines($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->invoiceLines = $values;
        return $this;
    }

    /**
     * Get invoiceLines.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Invoice_Line
     */
    public function getInvoiceLines($index = null)
    {
        if($index !== null) {
            return $this->invoiceLines[$index];
        }
        return $this->invoiceLines;
    }


}