<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @version Sun, 21 Aug 2011 18:32:21 +0000
 */
abstract class Carerix_Api_Rest_Entity_Abstract_Week_Hour_View extends Carerix_Api_Rest_Entity
{

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $weekMondayDate = null;

    /**
     * @access private
     * @var float
     * @value-class NSDecimalNumber
     * @allows-null 0
     */
    public $hoursTotal = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $creationDate = null;

    /**
     * @access private
     * @var string
     * @value-class NSCalendarDate
     * @allows-null 0
     */
    public $modificationDate = null;

    /**
     * @access private
     * @var integer
     * @value-class NSNumber
     * @allows-null 0
     * @value-type i
     * @value-type-human long integer (32 bits)
     */
    public $employeeID = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Entity_Employee
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Employee")
     * @mandatory 0
     * @destination-entity CREmployee
     * @to-many 0
     * @name toEmployee
     */
    public $toEmployee = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Week_Hour")
     * @mandatory 0
     * @destination-entity CRWeekHour
     * @to-many 1
     * @name allWeekHours
     */
    public $allWeekHours = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Week_Hour_Job_View")
     * @mandatory 0
     * @destination-entity CRWeekHourJobView
     * @to-many 1
     * @name weekHourJobViews
     */
    public $weekHourJobViews = null;

    /**
     * @access private
     * @var Carerix_Api_Rest_Collection
     * @OneToMany (targetEntity="Carerix_Api_Rest_Entity_Attachment")
     * @mandatory 0
     * @destination-entity CRAttachment
     * @to-many 1
     * @name attachments
     */
    public $attachments = null;

    public static function configure(Carerix_Api_Rest_EntityConfiguration $entityConfiguration)
    {
        parent::configure($entityConfiguration);
        $entityConfiguration->setIdentifierKey("weekHourViewID");
        $entityConfiguration->setName("week-hour-view");
    }

    /**
     * Set weekMondayDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setWeekMondayDate($value)
    {
        $this->weekMondayDate = $value;
        return $this;
    }

    /**
     * Get weekMondayDate.
     *
     * @return string
     */
    public function getWeekMondayDate()
    {
        return $this->weekMondayDate;
    }

    /**
     * Set hoursTotal.
     *
     * Provides a fluent interface.
     *
     * @param float $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setHoursTotal($value)
    {
        $this->hoursTotal = $value;
        return $this;
    }

    /**
     * Get hoursTotal.
     *
     * @return float
     */
    public function getHoursTotal()
    {
        return $this->hoursTotal;
    }

    /**
     * Set creationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setCreationDate($value)
    {
        $this->creationDate = $value;
        return $this;
    }

    /**
     * Get creationDate.
     *
     * @return string
     */
    public function getCreationDate()
    {
        return $this->creationDate;
    }

    /**
     * Set modificationDate.
     *
     * Provides a fluent interface.
     *
     * @param string $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setModificationDate($value)
    {
        $this->modificationDate = $value;
        return $this;
    }

    /**
     * Get modificationDate.
     *
     * @return string
     */
    public function getModificationDate()
    {
        return $this->modificationDate;
    }

    /**
     * Set employeeID.
     *
     * Provides a fluent interface.
     *
     * @param integer $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setEmployeeID($value)
    {
        $this->employeeID = $value;
        return $this;
    }

    /**
     * Get employeeID.
     *
     * @return integer
     */
    public function getEmployeeID()
    {
        return $this->employeeID;
    }

    /**
     * Set toEmployee.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Entity_Employee $value
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setToEmployee($value)
    {
        if(is_array($value)) {
            $value = new Carerix_Api_Rest_Entity_Employee($value); 
        }                 
        $this->toEmployee = $value;
        return $this;
    }

    /**
     * Get toEmployee.
     *
     * @return Carerix_Api_Rest_Entity_Employee
     */
    public function getToEmployee()
    {
        return $this->toEmployee;
    }

    /**
     * Set allWeekHours.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setAllWeekHours($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->allWeekHours = $values;
        return $this;
    }

    /**
     * Get allWeekHours.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Week_Hour
     */
    public function getAllWeekHours($index = null)
    {
        if($index !== null) {
            return $this->allWeekHours[$index];
        }
        return $this->allWeekHours;
    }

    /**
     * Set weekHourJobViews.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setWeekHourJobViews($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->weekHourJobViews = $values;
        return $this;
    }

    /**
     * Get weekHourJobViews.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Week_Hour_Job_View
     */
    public function getWeekHourJobViews($index = null)
    {
        if($index !== null) {
            return $this->weekHourJobViews[$index];
        }
        return $this->weekHourJobViews;
    }

    /**
     * Set attachments.
     *
     * Provides a fluent interface.
     *
     * @param array|Carerix_Api_Rest_Collection $values
     * @return Carerix_Api_Rest_Entity_Abstract_Week_Hour_View
     */
    public function setAttachments($values)
    {
        if(is_array($values)) {
            $values = new Carerix_Api_Rest_Collection($values); 
        } 
        $this->attachments = $values;
        return $this;
    }

    /**
     * Get attachments.
     *
     * @param $index [optional] integer get an item at specified index
     * @return Carerix_Api_Rest_Collection|Carerix_Api_Rest_Entity_Attachment
     */
    public function getAttachments($index = null)
    {
        if($index !== null) {
            return $this->attachments[$index];
        }
        return $this->attachments;
    }


}