<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @licence http://www.opensource.org/licenses/lgpl-license.php LGPL
 * @link http://www.carerix.com
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights
 * reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @build Thu, 21 Jul 2011 11:10:05 +0300
 */
class Carerix_Api_Rest_Entity_User extends Carerix_Api_Rest_Entity_Abstract_User
{  
    /**
     * Added for BC reasons.
     *  
     * toCompany
     * @var Carerix_Api_Rest_Entity_Company
     * @OneToOne (targetEntity="Carerix_Api_Rest_Entity_Company")
     * @access private
     */
    public $toCompany;
    
    /**
     * Gets toCompany
     *
     * @return Carerix_Api_Rest_Entity_Company
     */
    public function getToCompany() 
    {
        return $this->toCompany;
    }
    
    /**
     * Sets toCompany
     *
     * @param array|Carerix_Api_Rest_Entity_Company $toCompany toCompany
     * @return self
     */
    public function setToCompany($toCompany) 
    {
        if(is_array($toCompany)) {
            $toCompany = new Carerix_Api_Rest_Entity_Company($toCompany);
        }
        $this->toCompany = $toCompany;
        return $this;
    }
    
    /**
     * Get a list of meetings for a given user.
     * 
     * @param array $parameters [optional] e.g. array('startDate' => '-30 days', 'endDate' => 'now')
     * @param integer $hydrate [optional] hydration method 
     * @return Carerix_Api_Rest_Collection
     */
    public function meeting($parameters = null, $hydrate = null)
    {
        $args = func_get_args();
        switch(count($args)) {
            case 1:
                if(!is_array($args[0])) {
                    $parameters = array();
                    $hydrate = $args[0];                    
                }
            break;
        }
                
        if(!$this->getId()) {
            throw new Carerix_Api_Rest_Exception('Please load the object from the REST API first or set id.');
        }
        $parameters = array_merge((array) $parameters, array('userID' => $this->getId()));
         $get_called_class = get_class($this);
        $action = 'meeting';
        return self::$_manager->execute(
            'Carerix_Api_Rest_Entity_To_Do', 
            $this->generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate
        );        
    }
    
    /**
     * Get user object by auth. 
     * 
     * @param array $parameters 
     * @param integer $hydrate [optional] hydration method 
     * @return Carerix_Api_Rest_Entity_User
     * 
     * @see http://development.wiki.carerix.com/index.php/Cxrest_API_methods#GET_user.2Fget-by-auth
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */        
    public static function getByAuth(array $parameters, $hydrate = null)
    {
        $action = 'get-by-auth';
        $get_called_class = get_called_class();
        return self::$_manager->execute(
            $get_called_class,
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate            
        );
    }     

    /**
     * Get user object by username and hash. 
     * 
     * @param array $parameters
     * @param integer $hydrate [optional] hydration method  
     * @return Carerix_Api_Rest_Entity_User
     * 
     * @see http://development.wiki.carerix.com/index.php/Cxrest_API_methods#GET_user.2Fget-by-username-and-hash
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */        
    public static function getByUsernameAndHash(array $parameters, $hydrate = null)
    {    
        $action = 'get-by-username-and-hash';
        $get_called_class = get_called_class();
        return self::$_manager->execute(
            $get_called_class,
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate
        );
    }    

    /**
     * Get user token and id by userName,password, systemName and type. 
     * 
     * @param array $parameters
     * @param integer $hydrate [optional] hydration method 
     * @return mixed xml|array  
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */        
    public static function getTokenStatic(array $parameters, $hydrate = self::HYDRATE_ARRAY)
    {
        if(!in_array($hydrate, array(self::HYDRATE_NONE, self::HYDRATE_ARRAY))) {
            throw new Carerix_Api_Rest_Exception('Unsupported hydration mode for '.__METHOD__);
        }        
        $action = 'get-token';
        $get_called_class = get_called_class();
        $result = self::$_manager->execute(
            $get_called_class,
            self::generateUrl(get_defined_vars(), $get_called_class),
            Carerix_Api_Rest_Client::GET,
            null,
            null,
            $hydrate
        );
        
        return $result;        
    }

    /**
     * Get user token and id by systemName and type. 
     * 
     * @param array $parameters
     * @param integer $hydrate [optional] hydration method 
     * @return mixed xml|array  
     * 
     * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
     */         
    public function getToken(array $parameters, $hydrate = self::HYDRATE_ARRAY)
    {
        if(!$this->getUserName() || !$this->getPassword()) {
            throw new Carerix_Api_Rest_Exception('Please load the object from the REST API first or set userName and password before calling this method.');
        }
        $parameters = array_merge($parameters, array('userName' => $this->getUserName(), 'password' => $this->getPassword()));
        return Carerix_Api_Rest_Entity_User::getTokenStatic($parameters, $hydrate);
    }

    /**
     * (non-PHPdoc)
     * @see Carerix_Api_Rest_Entity::subscribe()
     * @return Carerix_Api_Rest_Entity_User
     */
    public function subscribe($parameters = null, $hydrate = null)
    {
        return parent::subscribe($parameters, $hydrate);    
    }
}