<?php
/**
 * Carerix PHP Library
 *
 * LICENSE
 *
 * This source file is subject to the LGPL license that is 
 * available through the world-wide-web at this URL:
 * http://www.opensource.org/licenses/lgpl-license.php
 *
 * @category Carerix
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 * @copyright Copyright (c) 2011 Carerix.com (http://www.carerix.com)
 * @license http://www.opensource.org/licenses/lgpl-license.php  LGPL
 * @link http://www.carerix.com
 * @version 2011-09-12 08:50:33Z
 */
 
/**
 * @category Carerix
 * @copyright Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.
 * @author Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>
 */

class Carerix_Api_Rest_EntityGenerator {

    const API_ENDPOINT = 'https://api.carerix.com';
    const ABSTRACT_CLASS = 'Carerix_Api_Rest_Entity';
    const COLLECTION_CLASS = 'Carerix_Api_Rest_Collection';
    
    /**
     * 
     * List of entities to generate data models for
     * @var array
     */
    protected $entities;
    
    public function setEntities($entities) {
        $this->entities = $entities;
        return $this;
    }    
    
    public function getEntities() {
        return $this->entities;
    }
    
    protected $username;
    
    public function setUsername($username) {
        $this->username = $username;
        return $this;
    }    
    
    public function getUsername() {
        return $this->username;
    }
    
    protected $password;
    
    public function setPassword($password) {
        $this->password = $password;
        return $this;
    }    
    
    public function getPassword() {
        return $this->password;
    }    
    
    public function getScheme($entity) {
        $entity = self::fromXmlEntityName($entity, '-');
        $entity = strtolower($entity);
        
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, self::API_ENDPOINT.'/'.$entity);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Expect:'));
        curl_setopt($ch, CURLOPT_PROXY, 'localhost:8888');
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($ch, CURLOPT_USERAGENT, __CLASS__);

        $username = $this->getUsername();
        $password = $this->getPassword();

        if ($username && $password) {
            curl_setopt ($ch, CURLOPT_USERPWD, $username . ':' . $password);
        }

        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'OPTIONS');

        $result = curl_exec($ch);

        if ( ! $result) {
            $errorNumber = curl_errno($ch);
            $error = curl_error($ch);
            curl_close($ch);

            throw new Exception($errorNumer . ': ' . $error);
        }

        curl_close($ch);
        
        return $result;
    }
    
    public function build($dir = null) {
        foreach($this->getEntities() as $entity) {
            
            try {
                $xml = $this->getScheme($entity);
            }
            catch (Exception $ex) {
                continue;
            }
            $entity = self::fromXmlEntityName($entity);
            
            $sxe = new SimpleXMLElement($xml);
            
            $entityClassName = self::ABSTRACT_CLASS.'_Abstract_'.$this->getEntityClassName($entity);
            $entityClassFileName = $this->getEntityClassFileName($entityClassName);
            $entityPath = $dir.'/'.$entityClassFileName;
            
            $class = new Zend_CodeGenerator_Php_Class();
            $class->setAbstract(true);
            $class->setName($entityClassName);
            $class->setExtendedClass(self::ABSTRACT_CLASS);
            $class->setDocblock(self::getClassDocblock());
            $this->addCommonMethods($entity, $class);
            
            // attributes
            foreach($sxe->attribute as $attribute) {
                $this->addAttribute($class, $attribute);
            }
            
            // relationships
            foreach($sxe->relationship as $relationship) {
                $this->addRelationship($class, $relationship);
            }            
            
            $code = $class->generate();
            $this->mkdir($entityPath);
            
            file_put_contents($entityPath, "<?php\n".$code);
            $sxe = $xml = $class = $code = null;
            
            // build concrete classes
            $entityClassName = self::ABSTRACT_CLASS.'_'.$this->getEntityClassName($entity);
            $entityClassFileName = $this->getEntityClassFileName($entityClassName);
            $entityPath = $dir.'/'.$entityClassFileName;
            
            $class = new Zend_CodeGenerator_Php_Class();
            $class->setName($entityClassName);
            $class->setExtendedClass(self::ABSTRACT_CLASS.'_Abstract_'.$this->getEntityClassName($entity));
            $class->setDocblock(self::getClassDocblock());
            
            $code = $class->generate();
            $this->mkdir($entityPath);
            // don't override existing concrete classes
            if(file_exists($entityPath)) {
                continue;
            }
            file_put_contents($entityPath, "<?php\n".$code);
            $class = $code = null;                        
        }
    }
    
    /**
     * 
     * Enter description here ...
     * @param Zend_CodeGenerator_Php_Class $class
     * @param SimpleXMLElement $attribute
     */
    protected function addAttribute(Zend_CodeGenerator_Php_Class &$class, SimpleXMLElement $attribute) {
    
        $paramType = self::normalizeVarType($attribute['value-class']);
        $optional = self::isOptionalAttribute($attribute);
        $property = array(
            'name' => (string)$attribute['name'],
            'visibility' => Zend_CodeGenerator_Php_Property::VISIBILITY_PUBLIC,
            'docblock' => array(
                'tags' => array(
                    array(
                        'name' => 'access',
                        'description'  => 'private',
                    ),        
                    array(
                        'name' => 'var',
                        'description'  => $paramType,
                    ),
                    array(
                        'name' => 'value-class',
                        'description'  => $attribute['value-class'],
                    ),
                    array(
                        'name' => 'allows-null',
                        'description'  => $attribute['allows-null'],
                    ),
                ) 
            )
        );
        
        switch($attribute['value-class']) {
            case 'NSString':
            case 'PRBitVector':
                $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'width',
                            'description'  => $attribute['width'],
                        ),    
                    )        
                )));
            break;
            
            case 'NSNumber':
                $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'value-type',
                            'description'  => $attribute['value-type'],
                        ),
                        array(
                            'name' => 'value-type-human',
                            'description'  => self::normalizeValueType($attribute['value-type']),
                        ),
                    )        
                )));
            break;
        }

        // @see GET https://api.carerix.com/data-node/describe
        if(property_exists($attribute, 'isUnique')) {
            $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'isUnique',
                            'description'  => (string) $attribute->isUnique,
                        ),    
                    )        
            )));            
        }        

        // set default value if any
        if(array_key_exists('default', $attribute)) {
            $property = array_merge_recursive($property, array(
                'value' =>  $attribute['default'],
            ));            
        }        
        
        $methodSet = new Zend_CodeGenerator_Php_Method();
        $docblockSet = new Zend_CodeGenerator_Php_Docblock();
        $docblockSet->setShortDescription('Set '.$attribute['name'].'.');
        $docblockSet->setLongDescription('Provides a fluent interface.');
        $docblockSet->setTags(array(
            array(
                'name' => 'param', 
                'description' => $paramType.' $value'.
                ($optional ? ' [optional]' : '').'',
//                'description' => $paramType.' $'.$attribute['name'].
//                ($optional ? ' [optional]' : '').'',
            ),
            array(
                'name' => 'return', 
                'description' => $class->getName(),
            ),                    
        ));
        
        $methodSet->setDocblock($docblockSet);
        $methodSet->setName('set'.ucfirst($attribute['name']));
        $methodSet->setParameter(array(
            'name' => 'value',
//            'name' => (string) $attribute['name'],
//            'defaultValue' => $optional ? '' : null,
        ));
//        $methodSet->setBody('$this->'.$attribute['name'].' = $'.$attribute['name'].';'."\n".'return $this;');
        $methodSet->setBody('$this->'.$attribute['name'].' = $value;'."\n".'return $this;');
        
        switch($attribute['value-class']) {
            case 'NSArray':
            case 'NSDictionary':
                $methodSet->setBody('if(is_array($value)) {
    $value = new Carerix_Api_Rest_DataType_'.$attribute['value-class'].'($value);
}
$this->'.$attribute['name'].' = $value;
return $this;');
            break;

        }
        $methodGet = new Zend_CodeGenerator_Php_Method();
        $docblockGet = new Zend_CodeGenerator_Php_Docblock();
        $docblockGet->setShortDescription('Get '.$attribute['name'].'.');
        $docblockGet->setTags(array(
            array(
                'name' => 'return', 
                'description' => $paramType,
            ),                    
        ));
        
        $methodGet->setDocblock($docblockGet);        
        $methodGet->setName('get'.ucfirst($attribute['name']));
        $methodGet->setBody('return $this->'.$attribute['name'].";\n");
        
        try {
            $class->setProperty($property);

            $class->setMethod($methodSet);
            $class->setMethod($methodGet);
        }
        catch (Exception $ex) {
            continue;
        }            
    }
    
    /**
     * 
     * @param string $value
     * @return string
     */
    public static function normalizeValueType($value) {
        switch($value) {
            case 's':
                return 'short integer (16 bits)';
            break;
            case 'i':
                return 'long integer (32 bits)';
            break;
        }            
    }
    
    /**
     * 
     * Enter description here ...
     * @param Zend_CodeGenerator_Php_Class $class
     * @param SimpleXMLElement $relationship
     */
    protected function addRelationship(Zend_CodeGenerator_Php_Class &$class, SimpleXMLElement $relationship) {
        $paramType = self::ABSTRACT_CLASS.'_'.self::fromXmlEntityName($relationship['destination-entity']);
        $property = array(
            'name' => (string)$relationship['name'],
            'visibility' => Zend_CodeGenerator_Php_Property::VISIBILITY_PUBLIC,
            'docblock' => array(
                'tags' => array(
                    array(
                        'name' => 'access',
                        'description'  => 'private',
                    ),            
                    array(
                        'name' => 'var',
//                        'description'  => self::isMany($relationship) ? 'array of '.$paramType : $paramType,
                        'description'  => self::isMany($relationship) ? self::COLLECTION_CLASS : $paramType,
                    ),
                    // doctrine-style docblock
                    array(
                        'name' => self::isMany($relationship) ? 'OneToMany' : 'OneToOne',
                        'description'  => '(targetEntity="'.$paramType.'")',
                    ),    
                    array(
                        'name' => 'mandatory',
                        'description'  => $relationship['mandatory'],
                    ),        
                    array(
                        'name' => 'destination-entity',
                        'description'  => $relationship['destination-entity'],
                    ),                                                
                    array(
                        'name' => 'to-many',
                        'description'  => $relationship['to-many'],
                    ),                                
                    array(
                        'name' => 'name',
                        'description'  => $relationship['name'],
                    ),                                                            
                ) 
            )
        );
        if(property_exists($relationship, 'qualifier')) {
            $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'qualifier',
                            'description'  => (string) $relationship->qualifier,
                        ),    
                    )        
            )));            
        }
        if(property_exists($relationship, 'default')) {
            $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'default',
                            'description'  => (string) $relationship->default,
                        ),    
                    )        
            )));            
        }
        if(property_exists($relationship, 'nodeType')) {
            $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'nodeType',
                            'description'  => (string) $relationship->nodeType,
                        ),    
                    )        
            )));            
        }
        // @see GET https://api.carerix.com/data-node/describe
        if(property_exists($relationship, 'inverseName')) {
            $property = array_merge_recursive($property, array(
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'inverseName',
                            'description'  => (string) $relationship->inverseName,
                        ),    
                    )        
            )));            
        }
                
        $methodSet = array(
            'name' => 'set'.ucfirst((string)$relationship['name']),
            'visibility' => Zend_CodeGenerator_Php_Property::VISIBILITY_PUBLIC,
            'parameters' => array(
                array(
//                    'name' => 'value',
                    'name' => self::isMany($relationship) ? 'values' : 'value',
//                    'type' => self::isMany($relationship) ? 'array' : $paramType,
//                    'type' => self::isMany($relationship) ? self::COLLECTION_CLASS : $paramType,
                )        
            ),
            'docblock' => array(
                'shortDescription' => 'Set '.$relationship['name'].'.',
                'longDescription' => 'Provides a fluent interface.',            
                'tags' => array(
                    array(
                        'name' => 'param', 
                        'description' => self::isMany($relationship) ? 'array|'.self::COLLECTION_CLASS.' $values' : 'array|'.$paramType.' $value',
//                        'description' => self::isMany($relationship) ? 'array $values array of '.$paramType : $paramType.' $value',
//                        (self::isOptionalRelationship($relationship) ? ' [optional]' : '').'',
                    ),
                    array(
                        'name' => 'return', 
                        'description' => $class->getName(),
                    ),        
                )
            ),
//            'body' => '$this->'.$relationship['name'].' = $value;'."\n".'return $this;',
//            'body' => '$this->'.$relationship['name'].' = $value'.(self::isMany($relationship) ? 's' : '').';'."\n".'return $this;',
            'body' => self::isMany($relationship) ? 
                'if(is_array($values)) {
    $values = new '.self::COLLECTION_CLASS.'($values); 
} 
$this->'.$relationship['name'].' = $values;'."\n".'return $this;' :
            
                'if(is_array($value)) {
    $value = new '.$paramType.'($value); 
}                 
$this->'.$relationship['name'].' = $value;'."\n".'return $this;',
            
        );        
        $methodGet = array();
        if(self::isMany($relationship)) {
            $methodGet = array(
                'parameters' => array(
                    array(
                        'name' => 'index',
                        'defaultValue' => null,
                    )        
                ),
                'docblock' => array(
                    'tags' => array(
                        array(
                            'name' => 'param', 
                            'description' => '$index [optional] integer get an item at specified index',
                        ),        
                    )
                )                    
            );
        }
                
        $methodGet = array_merge_recursive($methodGet, array(
            'name' => 'get'.ucfirst((string)$relationship['name']),
            'visibility' => Zend_CodeGenerator_Php_Property::VISIBILITY_PUBLIC,
            
            'docblock' => array(
                'shortDescription' => 'Get '.$relationship['name'].'.',
                'tags' => array(
                    array(
                        'name' => 'return', 
                        'description' => self::isMany($relationship) ? self::COLLECTION_CLASS.'|'.$paramType : $paramType,
//                        'description' => self::isMany($relationship) ? self::COLLECTION_CLASS.' of '.$paramType.' objects' : $paramType,
//                        'description' => self::isMany($relationship) ? 'array of '.$paramType : $paramType,
                    ),        
                )
            ),
            'body' => self::isMany($relationship) ? 
            'if($index !== null) {
    return $this->'.$relationship['name'].'[$index];
}
return $this->'.$relationship['name'].';' :
            'return $this->'.$relationship['name'].';',
        ));


        
        try {
            $class->setProperty($property);

            $class->setMethod($methodSet);
            $class->setMethod($methodGet);
        }
        catch (Exception $ex) {
        }    
    }
    
    protected function addCommonMethods($entity, Zend_CodeGenerator_Php_Class &$class) {
        $entityName = strtolower(self::getEntityName($entity, '_', '-'));
        
        $class->setMethods(array(
//            array(
//                'name' => 'construct', 
//                'visibility' => Zend_CodeGenerator_Php_Method::VISIBILITY_PUBLIC,
//                'parameter' => array(
//                    'name' => '$values',
//                    'type' => 'array',
//                    'defaultValue' => null,
//                ),
//                'body' => 'parent::configure($entityConfiguration);'.PHP_EOL.
//                '$entityConfiguration->setIdentifierKey("'.self::getIdentifierKey($entity).'");'.PHP_EOL.
//                '$entityConfiguration->setName("'.$entityName.'");',
//            ),        
            array(
                'name' => 'configure', 
                'static' => true, 
                'visibility' => Zend_CodeGenerator_Php_Method::VISIBILITY_PUBLIC,
                'parameter' => array(
                    'name' => 'entityConfiguration',
                    'type' => 'Carerix_Api_Rest_EntityConfiguration',
                ),
//                'body' => '$entityConfiguration->setUrl("'.self::API_ENDPOINT.'");'.PHP_EOL.
//                '$entityConfiguration->setName("'.strtolower($this->getEntityName($entity, '_', '-')).'");',
                'body' => 'parent::configure($entityConfiguration);'.PHP_EOL.
                '$entityConfiguration->setIdentifierKey("'.self::getIdentifierKey($entity).'");'.PHP_EOL.
                '$entityConfiguration->setName("'.$entityName.'");',
            ),        
//            array(
//                'name' => 'getCalledClass', 
//                'static' => true, 
//                'visibility' => Zend_CodeGenerator_Php_Method::VISIBILITY_PUBLIC,
//                'body' => 'return get_class();'
//            ),        
        ));
    }
    
    public static function getEntityName($entity, $explode = '-', $implode = '_') {
        $parts = explode($explode, $entity);
        $parts = array_map('ucfirst', $parts);
        return implode($implode, $parts);
    }
    
    public static function getIdentifierKey($entity) {
        $idk = self::getEntityName($entity, '_', '');
        return substr_replace($idk, strtolower(substr($idk, 0, 1)), 0, 1).'ID';
    }
    
    public static function getEntityClassName($entity) {
        return self::getEntityName($entity, '-', '_');
    }
    
    public static function getEntityClassFileName($entity) {
        return self::getEntityName($entity, '_', '/').'.php';
    }    
    
    protected function mkdir($filename) {
        $dir = dirname($filename);
        if(!is_dir($dir)) {
            mkdir($dir, 0755, true);
        }
    }
    
    /**
     * 
     * @param SimpleXMLElement $element
     * @return boolean
     */
    protected static function isMany(SimpleXMLElement $element) {
        return (string) $element['to-many'] == '1' ? true : false;
    }
    
    /**
     * 
     * @param SimpleXMLElement $element
     * @return boolean
     */    
    protected static function isOptionalAttribute(SimpleXMLElement $element) {
        return (string) $element['allows-null'] == '1' ? true : false;
    }
    
    /**
     * 
     * @param SimpleXMLElement $element
     * @return boolean
     */    
    protected static function isOptionalRelationship(SimpleXMLElement $element) {
        return (string) $element['mandatory'] == '0' ? true : false;
    }
    
    /**
     * 
     * Enter description here ...
     * @param string $type
     * @return string
     */
    protected static function normalizeVarType($type) {
        switch($type) {
            default:
            case 'NSData':
            case 'NSCalendarDate':
            case 'NSString':
            case 'PRBitVector':
                return 'string';
            break;
            
            case 'NSNumber':
                return 'integer';
            break;    
            
            case 'NSDecimalNumber':
                return 'float';
            break;    
                    

            case 'NSArray':
                return 'Carerix_Api_Rest_DataType_NSArray|array';
            break;        
                
            case 'NSDictionary':
                return 'Carerix_Api_Rest_DataType_NSDictionary|array';
            break;    
                    
//            case 'NSDictionary':
//            case 'NSArray':
//                return 'array';
//            break;            
        }
    }
    
    /**
     * Normalize NSDictionary
     * 
     * @param array $values
     * @return array
     */
    public static function normalizeNSDictionary($values) {
        $array = array();
        foreach($values as $k => $v) {
            if(substr($k, 0, 1) == '_') {
                $k = substr($k, 1);                
            }
            $array[$k] = $v;
        }
        return $array;
    }
    /**
     * 
     * Convert CREntity to entity
     * @param string $entity
     * @return string
     */
    public static function fromXmlEntityName($entity, $delimeter = '_') {
        if(substr($entity, 0, 2) == 'CR') {
            $entity = substr($entity, 2);
        }
        $entity = preg_replace('/([A-Z])/', $delimeter.'\\1', $entity);
        $entity = trim($entity, $delimeter);
        return $entity;
    }
        
    /**
     * 
     * Enter description here ...
     * @param string $entity
     * @return string
     */
    public static function toXmlEntityName($entity) {
        if(substr($entity, 0, 2) == 'CR') {
            return $entity;
        }
        $parts = explode('-', $entity);
        $parts = array_map('ucfirst', $parts);

        return 'CR'.implode('', $parts);
    }    
    
    /**
     * 
     * @return array
     */
    public static function getClassDocblock() {
        return array(
            'tags' => array(
                array(
                    'name' => 'category',
                    'description'  => 'Carerix',
                ),
                array(
                    'name' => 'licence',
                    'description'  => 'http://www.opensource.org/licenses/lgpl-license.php LGPL',
                ),
                array(
                    'name' => 'link',
                    'description'  => 'http://www.carerix.com',
                ),
                array(
                    'name' => 'copyright',
                    'description'  => 'Copyright 2011 Carerix (http://www.carerix.com). All rights reserved.',
                ),
                array(
                    'name' => 'author',
                    'description'  => 'Andrey Yakubovskiy <andrey.yakubovskiy@gmail.com>',
                ),
                array(
                    'name' => 'version',
                    'description'  => date('r'),
                ),
            )             
        );
    }
}